[java-oidc-common] branch main updated: Fix javadoc errors.

Henri Mikkonen henri.mikkonen at iki.fi
Wed Jun 21 13:52:47 UTC 2023


This is an automated email from the git hooks/post-receive script.

hjmikkon pushed a commit to branch main
in repository java-oidc-common.

View the commit online:
http://git.shibboleth.net/view/?p=java-oidc-common.git;a=commit;h=66627297fb795a2628dc58d3d9c71e6f0370cf21

The following commit(s) were added to refs/heads/main by this push:
     new 6662729  Fix javadoc errors.
6662729 is described below

commit 66627297fb795a2628dc58d3d9c71e6f0370cf21
Author: Henri Mikkonen <henri.mikkonen at iki.fi>
AuthorDate: Wed Jun 21 16:52:41 2023 +0300

    Fix javadoc errors.
---
 .../metadata/impl/AbstractDynamicHTTPFetchingStrategy.java  | 13 +++++++------
 .../oidc/metadata/impl/AbstractOIDCEntityResolver.java      |  1 +
 2 files changed, 8 insertions(+), 6 deletions(-)

diff --git a/oidc-common-metadata-impl/src/main/java/net/shibboleth/oidc/metadata/impl/AbstractOIDCEntityResolver.java b/oidc-common-metadata-impl/src/main/java/net/shibboleth/oidc/metadata/impl/AbstractOIDCEntityResolver.java
index 9464d3d..c464765 100644
--- a/oidc-common-metadata-impl/src/main/java/net/shibboleth/oidc/metadata/impl/AbstractOIDCEntityResolver.java
+++ b/oidc-common-metadata-impl/src/main/java/net/shibboleth/oidc/metadata/impl/AbstractOIDCEntityResolver.java
@@ -36,6 +36,7 @@ import net.shibboleth.shared.annotation.constraint.NotEmpty;
 import net.shibboleth.shared.component.AbstractIdentifiableInitializableComponent;
 import net.shibboleth.shared.component.ComponentInitializationException;
 import net.shibboleth.shared.logic.Constraint;
+import net.shibboleth.shared.resolver.Resolver;
 import net.shibboleth.shared.resolver.ResolverException;
 
 /**

diff --git a/oidc-common-metadata-impl/src/main/java/net/shibboleth/oidc/metadata/impl/AbstractDynamicHTTPFetchingStrategy.java b/oidc-common-metadata-impl/src/main/java/net/shibboleth/oidc/metadata/impl/AbstractDynamicHTTPFetchingStrategy.java
index ce7e08e..30a4799 100644
--- a/oidc-common-metadata-impl/src/main/java/net/shibboleth/oidc/metadata/impl/AbstractDynamicHTTPFetchingStrategy.java
+++ b/oidc-common-metadata-impl/src/main/java/net/shibboleth/oidc/metadata/impl/AbstractDynamicHTTPFetchingStrategy.java
@@ -52,6 +52,7 @@ import net.shibboleth.shared.component.ComponentInitializationException;
 import net.shibboleth.shared.logic.Constraint;
 import net.shibboleth.shared.primitive.StringSupport;
 import net.shibboleth.shared.resolver.CriteriaSet;
+import net.shibboleth.shared.resolver.ResolverException;
 
 /**
  * Abstract strategy for fetching metadata dynamically over HTTP.
@@ -64,7 +65,7 @@ public abstract class AbstractDynamicHTTPFetchingStrategy<MetadataType>
     
     
     /** MDC attribute representing the current request URI. Will be available during the execution of the 
-     * configured {@link ResponseHandler}. */
+     * configured {@link HttpClientResponseHandler}. */
     public static final String MDC_ATTRIB_CURRENT_REQUEST_URI = 
             AbstractDynamicHTTPFetchingStrategy.class.getName() + ".currentRequestURI";
     
@@ -139,11 +140,11 @@ public abstract class AbstractDynamicHTTPFetchingStrategy<MetadataType>
      * </p>
      * <ul>
      * <li>
-     * a {@link net.shibboleth.utilities.java.support.httpclient.TLSSocketFactory}
+     * a {@link net.shibboleth.shared.httpclient.TLSSocketFactory}
      * </li>
      * <li>
      * a {@link org.opensaml.security.httpclient.impl.SecurityEnhancedTLSSocketFactory} which wraps
      * an instance of {@link net.shibboleth.utilities.java.support.httpclient.TLSSocketFactory}, with
      * the latter likely configured in a "no trust" configuration.  This variant is required if either a
      * trust engine or a client TLS credential is to be used.
      * </li>
@@ -151,8 +152,8 @@ public abstract class AbstractDynamicHTTPFetchingStrategy<MetadataType>
      *
      * <p>
      * For convenience methods for building a 
      * {@link net.shibboleth.utilities.java.support.httpclient.TLSSocketFactory}, 
      * see {@link net.shibboleth.utilities.java.support.httpclient.HttpClientSupport}.
      * </p>
      *
      * <p>
@@ -242,7 +243,7 @@ public abstract class AbstractDynamicHTTPFetchingStrategy<MetadataType>
    }
     
     /**
-    * Build an appropriate instance of {@link HttpUriRequest} based on the input criteria set.
+    * Build an appropriate instance of {@link ClassicHttpRequest} based on the input criteria set.
     * 
     * @param criteria the input criteria set
     * @return the newly constructed request, or null if it can not be built from the supplied criteria
@@ -139,11 +140,11 @@ public abstract class AbstractDynamicHTTPFetchingStrategy<MetadataType>
      * <li>
      * a {@link org.opensaml.security.httpclient.impl.SecurityEnhancedTLSSocketFactory} which wraps
-     * an instance of {@link net.shibboleth.utilities.java.support.httpclient.TLSSocketFactory}, with
+     * an instance of {@link net.shibboleth.shared.httpclient.TLSSocketFactory}, with
      * the latter likely configured in a "no trust" configuration.  This variant is required if either a
      * trust engine or a client TLS credential is to be used.
@@ -151,8 +152,8 @@ public abstract class AbstractDynamicHTTPFetchingStrategy<MetadataType>
      * <p>
      * For convenience methods for building a 
-     * {@link net.shibboleth.utilities.java.support.httpclient.TLSSocketFactory}, 
-     * see {@link net.shibboleth.utilities.java.support.httpclient.HttpClientSupport}.
+     * {@link net.shibboleth.shared.httpclient.TLSSocketFactory}, 
+     * see {@link net.shibboleth.shared.httpclient.HttpClientSupport}.
      * </p>
      *
-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list